@@ -213,13 +213,6 @@ class DSI():
         """
         self.opt = self.default_opt.copy()
         return None
-    
-    def update_opt(self, new_opt):
-        """
-        Update current self.opt from contents of new_opt dictionary.
-        """
-        self.opt.update(new_opt)
-        return None
         
     def screen(self, constraints):
         """
@@ -249,7 +242,7 @@ class DSI():
         vio['SatFlag'] = False
         self.sat = sat
         self.vio = vio
-        return sat, vio
+        return None
     
     def help(self, print_opt = False):
         """
@@ -260,20 +253,20 @@ class DSI():
         print('# 1. Create instance of ds with data from DataFrame df')
         print('ds = dside.DSI(df)')
         print('# 2. Screen the points using the constraints (dictionary)')
-        print('p = ds.screen(constraints)')
+        print('ds.screen(constraints)')
         print('# 3. Find DSp boundaries based on vnames (list of variable names for the axes)')
-        print('shp = ds.find_DSp(vnames)')
+        print('ds.find_DSp(vnames)')
         print('# 4. Plot the design space and the samples')
-        print('r = ds.plot(vnames)')
+        print('ds.plot(vnames)')
         print('# 5. Plot the nominal point and AOR based on point x (list/numpy array)')
-        print('r = ds.find_AOR(x)')
+        print('ds.find_AOR(x)')
         print('# 6. Save the results in detailed output.txt file and output.pkl file')
         print("ds.send_output('output')")
         if print_opt:
             print('\n# ----- Options ----- #')
             for i in list(self.opt.keys()):
                 print(f'{i:10}: {self.opt[i]}')
-        return self.opt
+        return None
     
     def plot(self, vnames = None, opt = {}):
         """
@@ -455,7 +448,7 @@ class DSI():
         plt.tight_layout()
         if opt['save_flag']:
             plt.savefig(opt['save_name'], dpi = opt['save_dpi'])
-        return self.report
+        return None
     
     def find_DSp(self, vnames = None, opt = {}):
         """
@@ -489,8 +482,7 @@ class DSI():
             self.extra_points = extra_points
         a = opt['a']
         if a == None:
-            fdf = pd.concat([sat, vio], axis = 0)[vnames]
-            a = np.product(fdf[vnames].max() - fdf[vnames].min())
+            a = np.product(self.df[vnames].max())
 
         dim = len(vnames)
         if dim == 2:
@@ -515,6 +507,13 @@ class DSI():
             lb = opt['lb']
             ub = opt['ub']
             maxiter = opt['maxiter']
+            if print_flag:
+                print('Bisection search for alpha multiplier (radius)')
+                print(f'    tol: {tol:3.3e}  maxiter: {maxiter}')
+                print(f'    lb:  {lb:3.3e}  ub:      {ub:3.3e}')
+                print(f'____________________________________________________')
+                print(f'{"No iter":^10}|{"alpha multiplier":^20}|{"Violation Flag":^20}')
+                print(f'____________________________________________________')
             # Bisection algorithm
             for i in range(maxiter):
                 mp = lb + (ub - lb)/2
@@ -537,11 +536,11 @@ class DSI():
                     lb = mp
                     if ub - lb <= tol:
                         if print_flag:
-                            print(i + 1, mp, flag)
-                        sol_flag = f'[{i + 1}] Optimal amul found: {mp:6f}   alpha: {a*mp:6f}   Tol: {tol:1.3e}   Gap: {ub - lb:1.3e}\nvnum: {vnum}   maxvnum: {maxvnum}'
+                            print(f'{i + 1:^10}|{mp:^20.3e}|{str(flag):^20}')
+                        sol_flag = f'[{i + 1}] Optimal amul: {mp:1.4e}   alpha: {a*mp:1.3e}\nTol: {tol:1.3e}   Bisection Gap: {ub - lb:1.3e}\nvnum: {vnum}   maxvnum: {maxvnum}'
                         break
                 if print_flag:
-                    print(i + 1, mp, flag)
+                    print(f'{i + 1:^10}|{mp:^20.3e}|{str(flag):^20}')
             if (i + 1) == maxiter:
                 sol_flag = f'Max iterations reached: {maxiter} iterations  amul: {mp:6f}'
         if print_flag:
@@ -567,7 +566,7 @@ class DSI():
         end_t = time()
         comp_t = end_t - start_t
         self.report['time'] = comp_t
-        return shp
+        return None
     
     def alphashape_2D(self, P, alpha):
         """
@@ -642,8 +641,6 @@ class DSI():
     def alphashape_3D(self, P, alpha):
         """
         Calculate the alphashape boundary from a point cloud P (3D np array)
-        Adapted from Geun (https://stackoverflow.com/users/9091202/geun)
-        https://stackoverflow.com/a/58113037
 
         Compute the alpha shape (concave hull) of a set of 3D points.
         Parameters:
@@ -711,34 +708,6 @@ class DSI():
         shp['size'] = 420e-10
         return shp
 
-    def collect_frames(self, anielev = 10, sfolder = 'animation', sname = 'plot',\
-         leading_no = 0, sdpi = 100):
-        """
-        ONLY FOR 3D PLOTS
-        Collect .png images for animation of plot by rotating the 3D plot
-        720 images will be collected with 0.5 increments for a total of 1 whole rotation
-        Args:
-            ax ([type]): matplotlib axes
-            anielev ([type]): elevation of the figure
-            sfolder ([type]): string of the save folder
-            sname ([type]): save name of the pictures generated, 
-            will be followed by {i:04}.png
-            sdpi (int, optional): [saved picture dpi]. Defaults to 100.
-        """
-        import matplotlib.pyplot as plt
-        # Create save folder
-        import os
-        try:
-            os.makedirs(sfolder)
-        except FileExistsError:
-            print('Folder already exist')
-            
-        ax = self.ax
-        ax.view_init(elev = anielev, azim = 0)
-        for ii in range(0, 2*360, 1):
-                ax.azim += 0.5
-                plt.savefig(f'{sfolder}{sname}_frame_{leading_no + ii:04}.png',\
-                    dpi = sdpi)
     def inside2D(self, x, shp = None):
         """
         Returns False if x is not in self.shp, True otherwise (2D)
@@ -764,8 +733,6 @@ class DSI():
         """
         Returns False if x is not in self.shp, True otherwise (3D)
         x: list of [x, y, z], or [[x1, y1, z1], [x2, y2, z2], ...]
-        https://stackoverflow.com/a/57901916
-        https://stackoverflow.com/a/41851137/12056867
         """
         import numpy as np
         if shp == None:
@@ -1009,7 +976,7 @@ class DSI():
             plt.legend(loc = opt['legloc'],\
                 framealpha = opt['framealpha']).set_zorder(opt['legendzorder'])
         
-        return fs_R
+        return None
     
     def send_output(self, output_filename = 'DSI_output', appendix = False,\
             rp_pkl = False):
@@ -1040,9 +1007,9 @@ class DSI():
         f.write(f'\n# -------------------------- RESULTS -------------------------- #\n')
         f.write(f'Design space size: {rp["space_size"]:10f}\n')
         f.write(f'Number of samples in DSp: {self.sat.shape[0]}\n\n')
-        f.write(f'Average {rp["hmv"]["name"]}:    {rp["hmv"]["mean"]:10f}\n')
-        f.write(f'DS Maximum {rp["hmv"]["name"]}: {rp["hmv"]["max"]:10f}\n')
-        f.write(f'DS Minimum {rp["hmv"]["name"]}: {rp["hmv"]["min"]:10f}\n')
+        f.write(f'Average {rp["hmv"]["name"]}:    {rp["hmv"]["mean"]:10}\n')
+        f.write(f'DS Maximum {rp["hmv"]["name"]}: {rp["hmv"]["max"]:10}\n')
+        f.write(f'DS Minimum {rp["hmv"]["name"]}: {rp["hmv"]["min"]:10}\n')
         f.write(f'\n-----------------------------------------------------------------\n')
         f.write(f'Detailed maximum point: \n')
         if type(rp["hmv"]["max_sample"]) != str:
@@ -1085,11 +1052,11 @@ class DSI():
                             f.write(f'\nNumber of samples inside AOR:' +\
                                 f'{rep["nosam"]}\n')
                             f.write(f'Average {rep["hmv"]["name"]}:' +\
-                                f'{rep["hmv"]["mean"]:10f}\n')
+                                f'{rep["hmv"]["mean"]:10}\n')
                             f.write(f'DS Maximum {rep["hmv"]["name"]}:' +\
-                                f'{rep["hmv"]["max"]:10f}\n')
+                                f'{rep["hmv"]["max"]:10}\n')
                             f.write(f'DS Minimum {rep["hmv"]["name"]}:' +\
-                                f'{rep["hmv"]["min"]:10f}\n')
+                                f'{rep["hmv"]["min"]:10}\n')
                             f.write(f'\n-----------------------------------------------'+\
                                 '--------------------------------------------------\n')
                             f.write(f'Detailed maximum point: \n')
@@ -1127,4 +1094,4 @@ class DSI():
             with open(output_filename + '.pkl', 'wb') as handle:
                 pickle.dump(report_pkl, handle, protocol = pickle.HIGHEST_PROTOCOL)
             print(f'Pickle file saved at: {output_filename}.pkl')
-        return report_pkl
\ No newline at end of file
+        return None
\ No newline at end of file
